@@ -24,55 +24,49 @@ G_DEFINE_TYPE (SnapdGetApps, snapd_get_apps, snapd_request_get_type ())
 SnapdGetApps *
 _snapd_get_apps_new (GStrv snaps, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdGetApps *request;
-
-    request = SNAPD_GET_APPS (g_object_new (snapd_get_apps_get_type (),
-                                            "cancellable", cancellable,
-                                            "ready-callback", callback,
-                                            "ready-callback-data", user_data,
-                                            NULL));
+    SnapdGetApps *self = SNAPD_GET_APPS (g_object_new (snapd_get_apps_get_type (),
+                                                       "cancellable", cancellable,
+                                                       "ready-callback", callback,
+                                                       "ready-callback-data", user_data,
+                                                       NULL));
    if (snaps != NULL && snaps[0] != NULL)
-       request->snaps = g_strdupv (snaps);
+       self->snaps = g_strdupv (snaps);
 
-    return request;
+    return self;
 }
 
 void
-_snapd_get_apps_set_select (SnapdGetApps *request, const gchar *select)
+_snapd_get_apps_set_select (SnapdGetApps *self, const gchar *select)
 {
-    g_free (request->select);
-    request->select = g_strdup (select);
+    g_free (self->select);
+    self->select = g_strdup (select);
 }
 
 GPtrArray *
-_snapd_get_apps_get_apps (SnapdGetApps *request)
+_snapd_get_apps_get_apps (SnapdGetApps *self)
 {
-    return request->apps;
+    return self->apps;
 }
 
 static SoupMessage *
 generate_get_apps_request (SnapdRequest *request)
 {
-    SnapdGetApps *r = SNAPD_GET_APPS (request);
-    g_autoptr(GPtrArray) query_attributes = NULL;
-    g_autoptr(GString) path = NULL;
+    SnapdGetApps *self = SNAPD_GET_APPS (request);
 
-    query_attributes = g_ptr_array_new_with_free_func (g_free);
-    if (r->select != NULL) {
-        g_autofree gchar *escaped = soup_uri_encode (r->select, NULL);
+    g_autoptr(GPtrArray) query_attributes = g_ptr_array_new_with_free_func (g_free);
+    if (self->select != NULL) {
+        g_autofree gchar *escaped = soup_uri_encode (self->select, NULL);
         g_ptr_array_add (query_attributes, g_strdup_printf ("select=%s", escaped));
     }
-    if (r->snaps != NULL) {
-        g_autofree gchar *snaps_list = g_strjoinv (",", r->snaps);
+    if (self->snaps != NULL) {
+        g_autofree gchar *snaps_list = g_strjoinv (",", self->snaps);
         g_ptr_array_add (query_attributes, g_strdup_printf ("names=%s", snaps_list));
     }
 
-    path = g_string_new ("http://snapd/v2/apps");
+    g_autoptr(GString) path = g_string_new ("http://snapd/v2/apps");
     if (query_attributes->len > 0) {
-        guint i;
-
         g_string_append_c (path, '?');
-        for (i = 0; i < query_attributes->len; i++) {
+        for (guint i = 0; i < query_attributes->len; i++) {
             if (i != 0)
                 g_string_append_c (path, '&');
             g_string_append (path, (gchar *) query_attributes->pdata[i]);
@@ -85,23 +79,27 @@ generate_get_apps_request (SnapdRequest *request)
 static gboolean
 parse_get_apps_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetApps *r = SNAPD_GET_APPS (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonArray) result = NULL;
-    GPtrArray *apps;
+    SnapdGetApps *self = SNAPD_GET_APPS (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_a (response, error);
+    g_autoptr(JsonArray) result = _snapd_json_get_sync_result_a (response, error);
     if (result == NULL)
         return FALSE;
 
-    apps = _snapd_json_parse_app_array (result, error);
-    if (apps == NULL)
-        return FALSE;
+    g_autoptr(GPtrArray) apps = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (result); i++) {
+        JsonNode *node = json_array_get_element (result, i);
 
-    r->apps = g_steal_pointer (&apps);
+        SnapdApp *app = _snapd_json_parse_app (node, NULL, error);
+        if (app == NULL)
+            return FALSE;
+
+        g_ptr_array_add (apps, app);
+    }
+
+    self->apps = g_steal_pointer (&apps);
 
     return TRUE;
 }
@@ -109,11 +107,11 @@ parse_get_apps_response (SnapdRequest *request, SoupMessage *message, SnapdMaint
 static void
 snapd_get_apps_finalize (GObject *object)
 {
-    SnapdGetApps *request = SNAPD_GET_APPS (object);
+    SnapdGetApps *self = SNAPD_GET_APPS (object);
 
-    g_clear_pointer (&request->select, g_free);
-    g_clear_pointer (&request->snaps, g_strfreev);
-    g_clear_pointer (&request->apps, g_ptr_array_unref);
+    g_clear_pointer (&self->select, g_free);
+    g_clear_pointer (&self->snaps, g_strfreev);
+    g_clear_pointer (&self->apps, g_ptr_array_unref);
 
     G_OBJECT_CLASS (snapd_get_apps_parent_class)->finalize (object);
 }
@@ -130,6 +128,6 @@ snapd_get_apps_class_init (SnapdGetAppsClass *klass)
 }
 
 static void
-snapd_get_apps_init (SnapdGetApps *request)
+snapd_get_apps_init (SnapdGetApps *self)
 {
 }
