@@ -31,9 +31,9 @@ _snapd_get_users_new (GCancellable *cancellable, GAsyncReadyCallback callback, g
 }
 
 GPtrArray *
-_snapd_get_users_get_users_information (SnapdGetUsers *request)
+_snapd_get_users_get_users_information (SnapdGetUsers *self)
 {
-    return request->users_information;
+    return self->users_information;
 }
 
 static SoupMessage *
@@ -45,39 +45,27 @@ generate_get_users_request (SnapdRequest *request)
 static gboolean
 parse_get_users_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdGetUsers *r = SNAPD_GET_USERS (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonArray) result = NULL;
-    g_autoptr(GPtrArray) users_information = NULL;
-    guint i;
+    SnapdGetUsers *self = SNAPD_GET_USERS (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_a (response, error);
+    g_autoptr(JsonArray) result = _snapd_json_get_sync_result_a (response, error);
     if (result == NULL)
         return FALSE;
 
-    users_information = g_ptr_array_new_with_free_func (g_object_unref);
-    for (i = 0; i < json_array_get_length (result); i++) {
+    g_autoptr(GPtrArray) users_information = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (result); i++) {
         JsonNode *node = json_array_get_element (result, i);
-        SnapdUserInformation *user_information;
 
-        if (json_node_get_value_type (node) != JSON_TYPE_OBJECT) {
-            g_set_error (error,
-                         SNAPD_ERROR,
-                         SNAPD_ERROR_READ_FAILED,
-                         "Unexpected user information type");
-            return FALSE;
-        }
-
-        user_information = _snapd_json_parse_user_information (json_node_get_object (node), error);
+        SnapdUserInformation *user_information = _snapd_json_parse_user_information (node, error);
         if (user_information == NULL)
             return FALSE;
+
         g_ptr_array_add (users_information, user_information);
     }
 
-    r->users_information = g_steal_pointer (&users_information);
+    self->users_information = g_steal_pointer (&users_information);
 
     return TRUE;
 }
@@ -85,9 +73,9 @@ parse_get_users_response (SnapdRequest *request, SoupMessage *message, SnapdMain
 static void
 snapd_get_users_finalize (GObject *object)
 {
-    SnapdGetUsers *request = SNAPD_GET_USERS (object);
+    SnapdGetUsers *self = SNAPD_GET_USERS (object);
 
-    g_clear_pointer (&request->users_information, g_ptr_array_unref);
+    g_clear_pointer (&self->users_information, g_ptr_array_unref);
 
     G_OBJECT_CLASS (snapd_get_users_parent_class)->finalize (object);
 }
@@ -104,6 +92,6 @@ snapd_get_users_class_init (SnapdGetUsersClass *klass)
 }
 
 static void
-snapd_get_users_init (SnapdGetUsers *request)
+snapd_get_users_init (SnapdGetUsers *self)
 {
 }
