@@ -26,52 +26,47 @@ G_DEFINE_TYPE (SnapdPostChange, snapd_post_change, snapd_request_get_type ())
 SnapdPostChange *
 _snapd_post_change_new (const gchar *change_id, const gchar *action, GCancellable *cancellable, GAsyncReadyCallback callback, gpointer user_data)
 {
-    SnapdPostChange *request;
+    SnapdPostChange *self = SNAPD_POST_CHANGE (g_object_new (snapd_post_change_get_type (),
+                                                             "cancellable", cancellable,
+                                                             "ready-callback", callback,
+                                                             "ready-callback-data", user_data,
+                                                             NULL));
+    self->change_id = g_strdup (change_id);
+    self->action = g_strdup (action);
 
-    request = SNAPD_POST_CHANGE (g_object_new (snapd_post_change_get_type (),
-                                              "cancellable", cancellable,
-                                              "ready-callback", callback,
-                                              "ready-callback-data", user_data,
-                                              NULL));
-    request->change_id = g_strdup (change_id);
-    request->action = g_strdup (action);
-
-    return request;
+    return self;
 }
 
 const gchar *
-_snapd_post_change_get_change_id (SnapdPostChange *request)
+_snapd_post_change_get_change_id (SnapdPostChange *self)
 {
-    return request->change_id;
+    return self->change_id;
 }
 
 SnapdChange *
-_snapd_post_change_get_change (SnapdPostChange *request)
+_snapd_post_change_get_change (SnapdPostChange *self)
 {
-    return request->change;
+    return self->change;
 }
 
 JsonNode *
-_snapd_post_change_get_data (SnapdPostChange *request)
+_snapd_post_change_get_data (SnapdPostChange *self)
 {
-    return request->data;
+    return self->data;
 }
 
 static SoupMessage *
 generate_post_change_request (SnapdRequest *request)
 {
-    SnapdPostChange *r = SNAPD_POST_CHANGE (request);
-    g_autofree gchar *path = NULL;
-    SoupMessage *message;
-    g_autoptr(JsonBuilder) builder = NULL;
+    SnapdPostChange *self = SNAPD_POST_CHANGE (request);
 
-    path = g_strdup_printf ("http://snapd/v2/changes/%s", r->change_id);
-    message = soup_message_new ("POST", path);
+    g_autofree gchar *path = g_strdup_printf ("http://snapd/v2/changes/%s", self->change_id);
+    SoupMessage *message = soup_message_new ("POST", path);
 
-    builder = json_builder_new ();
+    g_autoptr(JsonBuilder) builder = json_builder_new ();
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "action");
-    json_builder_add_string_value (builder, r->action);
+    json_builder_add_string_value (builder, self->action);
     json_builder_end_object (builder);
     _snapd_json_set_body (message, builder);
 
@@ -81,22 +76,23 @@ generate_post_change_request (SnapdRequest *request)
 static gboolean
 parse_post_change_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdPostChange *r = SNAPD_POST_CHANGE (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonObject) result = NULL;
+    SnapdPostChange *self = SNAPD_POST_CHANGE (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_o (response, error);
+    /* FIXME: Needs json-glib to be fixed to use json_node_unref */
+    /*g_autoptr(JsonNode) result = NULL;*/
+    JsonNode *result = _snapd_json_get_sync_result (response, error);
     if (result == NULL)
         return FALSE;
 
-    r->change = _snapd_json_parse_change (result, error);
-    if (r->change == NULL)
+    self->change = _snapd_json_parse_change (result, error);
+    json_node_unref (result);
+    if (self->change == NULL)
         return FALSE;
 
-    if (g_strcmp0 (r->change_id, snapd_change_get_id (r->change)) != 0) {
+    if (g_strcmp0 (self->change_id, snapd_change_get_id (self->change)) != 0) {
         g_set_error (error,
                      SNAPD_ERROR,
                      SNAPD_ERROR_READ_FAILED,
@@ -104,8 +100,8 @@ parse_post_change_response (SnapdRequest *request, SoupMessage *message, SnapdMa
         return FALSE;
     }
 
-    if (json_object_has_member (result, "data"))
-        r->data = json_node_ref (json_object_get_member (result, "data"));
+    if (json_object_has_member (json_node_get_object (result), "data"))
+        self->data = json_node_ref (json_object_get_member (json_node_get_object (result), "data"));
 
     return TRUE;
 }
@@ -113,12 +109,12 @@ parse_post_change_response (SnapdRequest *request, SoupMessage *message, SnapdMa
 static void
 snapd_post_change_finalize (GObject *object)
 {
-    SnapdPostChange *request = SNAPD_POST_CHANGE (object);
+    SnapdPostChange *self = SNAPD_POST_CHANGE (object);
 
-    g_clear_pointer (&request->change_id, g_free);
-    g_clear_pointer (&request->action, g_free);
-    g_clear_object (&request->change);
-    g_clear_pointer (&request->data, json_node_unref);
+    g_clear_pointer (&self->change_id, g_free);
+    g_clear_pointer (&self->action, g_free);
+    g_clear_object (&self->change);
+    g_clear_pointer (&self->data, json_node_unref);
 
     G_OBJECT_CLASS (snapd_post_change_parent_class)->finalize (object);
 }
@@ -135,6 +131,6 @@ snapd_post_change_class_init (SnapdPostChangeClass *klass)
 }
 
 static void
-snapd_post_change_init (SnapdPostChange *request)
+snapd_post_change_init (SnapdPostChange *self)
 {
 }
