@@ -31,20 +31,17 @@ _snapd_post_create_users_new (GCancellable *cancellable, GAsyncReadyCallback cal
 }
 
 GPtrArray *
-_snapd_post_create_users_get_users_information (SnapdPostCreateUsers *request)
+_snapd_post_create_users_get_users_information (SnapdPostCreateUsers *self)
 {
-    return request->users_information;
+    return self->users_information;
 }
 
 static SoupMessage *
 generate_post_create_users_request (SnapdRequest *request)
 {
-    SoupMessage *message;
-    g_autoptr(JsonBuilder) builder = NULL;
+    SoupMessage *message = soup_message_new ("POST", "http://snapd/v2/create-user");
 
-    message = soup_message_new ("POST", "http://snapd/v2/create-user");
-
-    builder = json_builder_new ();
+    g_autoptr(JsonBuilder) builder = json_builder_new ();
     json_builder_begin_object (builder);
     json_builder_set_member_name (builder, "known");
     json_builder_add_boolean_value (builder, TRUE);
@@ -57,39 +54,27 @@ generate_post_create_users_request (SnapdRequest *request)
 static gboolean
 parse_post_create_users_response (SnapdRequest *request, SoupMessage *message, SnapdMaintenance **maintenance, GError **error)
 {
-    SnapdPostCreateUsers *r = SNAPD_POST_CREATE_USERS (request);
-    g_autoptr(JsonObject) response = NULL;
-    g_autoptr(JsonArray) result = NULL;
-    g_autoptr(GPtrArray) users_information = NULL;
-    guint i;
+    SnapdPostCreateUsers *self = SNAPD_POST_CREATE_USERS (request);
 
-    response = _snapd_json_parse_response (message, maintenance, error);
+    g_autoptr(JsonObject) response = _snapd_json_parse_response (message, maintenance, error);
     if (response == NULL)
         return FALSE;
-    result = _snapd_json_get_sync_result_a (response, error);
+    g_autoptr(JsonArray) result = _snapd_json_get_sync_result_a (response, error);
     if (result == NULL)
         return FALSE;
 
-    users_information = g_ptr_array_new_with_free_func (g_object_unref);
-    for (i = 0; i < json_array_get_length (result); i++) {
+    g_autoptr(GPtrArray) users_information = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (result); i++) {
         JsonNode *node = json_array_get_element (result, i);
         SnapdUserInformation *user_information;
 
-        if (json_node_get_value_type (node) != JSON_TYPE_OBJECT) {
-            g_set_error (error,
-                         SNAPD_ERROR,
-                         SNAPD_ERROR_READ_FAILED,
-                         "Unexpected user information type");
-            return FALSE;
-        }
-
-        user_information = _snapd_json_parse_user_information (json_node_get_object (node), error);
+        user_information = _snapd_json_parse_user_information (node, error);
         if (user_information == NULL)
             return FALSE;
         g_ptr_array_add (users_information, user_information);
     }
 
-    r->users_information = g_steal_pointer (&users_information);
+    self->users_information = g_steal_pointer (&users_information);
 
     return TRUE;
 }
@@ -97,9 +82,9 @@ parse_post_create_users_response (SnapdRequest *request, SoupMessage *message, S
 static void
 snapd_post_create_users_finalize (GObject *object)
 {
-    SnapdPostCreateUsers *request = SNAPD_POST_CREATE_USERS (object);
+    SnapdPostCreateUsers *self = SNAPD_POST_CREATE_USERS (object);
 
-    g_clear_pointer (&request->users_information, g_ptr_array_unref);
+    g_clear_pointer (&self->users_information, g_ptr_array_unref);
 
     G_OBJECT_CLASS (snapd_post_create_users_parent_class)->finalize (object);
 }
@@ -116,6 +101,6 @@ snapd_post_create_users_class_init (SnapdPostCreateUsersClass *klass)
 }
 
 static void
-snapd_post_create_users_init (SnapdPostCreateUsers *request)
+snapd_post_create_users_init (SnapdPostCreateUsers *self)
 {
 }
