@@ -91,11 +91,28 @@ typedef enum
     SNAPD_GET_APPS_FLAGS_SELECT_SERVICES = 1 << 0
 } SnapdGetAppsFlags;
 
+/**
+ * SnapdGetConnectionsFlags:
+ * @SNAPD_GET_CONNECTIONS_FLAGS_NONE: No flags, default behaviour.
+ * @SNAPD_GET_CONNECTIONS_FLAGS_SELECT_ALL: Select all connections, not just connected ones.
+ *
+ * Flag to change how connections are returned.
+ *
+ * Since: 1.49
+ */
+typedef enum
+{
+    SNAPD_GET_CONNECTIONS_FLAGS_NONE       = 0,
+    SNAPD_GET_CONNECTIONS_FLAGS_SELECT_ALL = 1 << 0,
+} SnapdGetConnectionsFlags;
+
 /**
  * SnapdFindFlags:
  * @SNAPD_FIND_FLAGS_NONE: No flags, default behaviour.
  * @SNAPD_FIND_FLAGS_MATCH_NAME: Search for snaps whose name matches the given
  *     string. The match is exact unless the string ends in *.
+ * @SNAPD_FIND_FLAGS_MATCH_COMMON_ID: Search for snaps whose common ID matches
+ *     the given string.
  * @SNAPD_FIND_FLAGS_SELECT_PRIVATE: Search private snaps.
  * @SNAPD_FIND_FLAGS_SELECT_REFRESH: Deprecated, do not use.
  * @SNAPD_FIND_FLAGS_SCOPE_WIDE: Search for snaps from any architecture or branch.
@@ -110,7 +127,8 @@ typedef enum
     SNAPD_FIND_FLAGS_MATCH_NAME      = 1 << 0,
     SNAPD_FIND_FLAGS_SELECT_PRIVATE  = 1 << 1,
     SNAPD_FIND_FLAGS_SELECT_REFRESH  = 1 << 2,
-    SNAPD_FIND_FLAGS_SCOPE_WIDE      = 1 << 3
+    SNAPD_FIND_FLAGS_SCOPE_WIDE      = 1 << 3,
+    SNAPD_FIND_FLAGS_MATCH_COMMON_ID = 1 << 4
 } SnapdFindFlags;
 
 /**
@@ -153,6 +171,27 @@ typedef enum
     SNAPD_CREATE_USER_FLAGS_KNOWN = 1 << 1
 } SnapdCreateUserFlags;
 
+/**
+ * SnapdGetInterfacesFlags:
+ * @SNAPD_GET_INTERFACES_FLAGS_NONE: No flags, default behaviour.
+ * @SNAPD_GET_INTERFACES_FLAGS_INCLUDE_DOCS: Include interface documentation.
+ * @SNAPD_GET_INTERFACES_FLAGS_INCLUDE_PLUGS: Include associated plugs.
+ * @SNAPD_GET_INTERFACES_FLAGS_INCLUDE_SLOTS: Include associated slots.
+ * @SNAPD_GET_INTERFACES_FLAGS_ONLY_CONNECTED: Only return connected interfaces.
+ *
+ * Flags to control how interface information is returned.
+ *
+ * Since: 1.48
+ */
+typedef enum
+{
+    SNAPD_GET_INTERFACES_FLAGS_NONE           = 0,
+    SNAPD_GET_INTERFACES_FLAGS_INCLUDE_DOCS   = 1 << 0,
+    SNAPD_GET_INTERFACES_FLAGS_INCLUDE_PLUGS  = 1 << 1,
+    SNAPD_GET_INTERFACES_FLAGS_INCLUDE_SLOTS  = 1 << 2,
+    SNAPD_GET_INTERFACES_FLAGS_ONLY_CONNECTED = 1 << 3,
+} SnapdGetInterfacesFlags;
+
 /**
  * SnapdProgressCallback:
  * @client: a #SnapdClient
@@ -355,6 +394,36 @@ SnapdSnap              *snapd_client_get_snap_finish               (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+GHashTable             *snapd_client_get_snap_conf_sync            (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GStrv                 keys,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_snap_conf_async           (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GStrv                 keys,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GHashTable             *snapd_client_get_snap_conf_finish          (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+gboolean                snapd_client_set_snap_conf_sync            (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GHashTable           *key_values,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_set_snap_conf_async           (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    GHashTable           *key_values,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_set_snap_conf_finish          (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 GPtrArray              *snapd_client_get_apps_sync                 (SnapdClient          *client,
                                                                     SnapdGetAppsFlags     flags,
                                                                     GCancellable         *cancellable,
@@ -426,15 +495,74 @@ gboolean                snapd_client_get_interfaces_sync           (SnapdClient
                                                                     GPtrArray           **plugs,
                                                                     GPtrArray           **slots,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_connections_sync);
 void                    snapd_client_get_interfaces_async          (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_get_connections_async);
 gboolean                snapd_client_get_interfaces_finish         (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GPtrArray           **plugs,
                                                                     GPtrArray           **slots,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_connections_finish);
+
+GPtrArray              *snapd_client_get_interfaces2_sync          (SnapdClient          *client,
+                                                                    SnapdGetInterfacesFlags flags,
+                                                                    GStrv                 names,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_interfaces2_async         (SnapdClient          *client,
+                                                                    SnapdGetInterfacesFlags flags,
+                                                                    GStrv                 names,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GPtrArray              *snapd_client_get_interfaces2_finish        (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+gboolean                snapd_client_get_connections_sync          (SnapdClient          *client,
+                                                                    GPtrArray           **established,
+                                                                    GPtrArray           **undesired,
+                                                                    GPtrArray           **plugs,
+                                                                    GPtrArray           **slots,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_connections2_sync);
+void                    snapd_client_get_connections_async         (SnapdClient          *client,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_get_connections2_async);
+gboolean                snapd_client_get_connections_finish        (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GPtrArray           **established,
+                                                                    GPtrArray           **undesired,
+                                                                    GPtrArray           **plugs,
+                                                                    GPtrArray           **slots,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_get_connections2_finish);
+
+gboolean                snapd_client_get_connections2_sync         (SnapdClient          *client,
+                                                                    SnapdGetConnectionsFlags flags,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *interface,
+                                                                    GPtrArray           **established,
+                                                                    GPtrArray           **undesired,
+                                                                    GPtrArray           **plugs,
+                                                                    GPtrArray           **slots,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_connections2_async        (SnapdClient          *client,
+                                                                    SnapdGetConnectionsFlags flags,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *interface,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_get_connections2_finish       (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GPtrArray           **established,
+                                                                    GPtrArray           **undesired,
+                                                                    GPtrArray           **plugs,
+                                                                    GPtrArray           **slots,
                                                                     GError              **error);
 
 gboolean                snapd_client_connect_interface_sync        (SnapdClient          *client,
