@@ -22,13 +22,18 @@
 #include <snapd-glib/snapd-enum-types.h>
 #include <snapd-glib/snapd-error.h>
 #include <snapd-glib/snapd-icon.h>
+#include <snapd-glib/snapd-interface.h>
 #include <snapd-glib/snapd-login.h>
 #include <snapd-glib/snapd-maintenance.h>
+#include <snapd-glib/snapd-markdown-node.h>
+#include <snapd-glib/snapd-markdown-parser.h>
 #include <snapd-glib/snapd-media.h>
 #include <snapd-glib/snapd-plug.h>
+#include <snapd-glib/snapd-plug-ref.h>
 #include <snapd-glib/snapd-price.h>
 #include <snapd-glib/snapd-screenshot.h>
 #include <snapd-glib/snapd-slot.h>
+#include <snapd-glib/snapd-slot-ref.h>
 #include <snapd-glib/snapd-snap.h>
 #include <snapd-glib/snapd-system-information.h>
 #include <snapd-glib/snapd-task.h>
