@@ -58,10 +58,10 @@ G_DEFINE_TYPE (SnapdIcon, snapd_icon, G_TYPE_OBJECT)
  * Since: 1.0
  */
 const gchar *
-snapd_icon_get_mime_type (SnapdIcon *icon)
+snapd_icon_get_mime_type (SnapdIcon *self)
 {
-    g_return_val_if_fail (SNAPD_IS_ICON (icon), NULL);
-    return icon->mime_type;
+    g_return_val_if_fail (SNAPD_IS_ICON (self), NULL);
+    return self->mime_type;
 }
 
 /**
@@ -75,26 +75,26 @@ snapd_icon_get_mime_type (SnapdIcon *icon)
  * Since: 1.0
  */
 GBytes *
-snapd_icon_get_data (SnapdIcon *icon)
+snapd_icon_get_data (SnapdIcon *self)
 {
-    g_return_val_if_fail (SNAPD_IS_ICON (icon), NULL);
-    return icon->data;
+    g_return_val_if_fail (SNAPD_IS_ICON (self), NULL);
+    return self->data;
 }
 
 static void
 snapd_icon_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
-    SnapdIcon *icon = SNAPD_ICON (object);
+    SnapdIcon *self = SNAPD_ICON (object);
 
     switch (prop_id) {
     case PROP_MIME_TYPE:
-        g_free (icon->mime_type);
-        icon->mime_type = g_strdup (g_value_get_string (value));
+        g_free (self->mime_type);
+        self->mime_type = g_strdup (g_value_get_string (value));
         break;
     case PROP_DATA:
-        g_clear_pointer (&icon->data, g_bytes_unref);
+        g_clear_pointer (&self->data, g_bytes_unref);
         if (g_value_get_boxed (value) != NULL)
-            icon->data = g_bytes_ref (g_value_get_boxed (value));
+            self->data = g_bytes_ref (g_value_get_boxed (value));
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -105,14 +105,14 @@ snapd_icon_set_property (GObject *object, guint prop_id, const GValue *value, GP
 static void
 snapd_icon_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
-    SnapdIcon *icon = SNAPD_ICON (object);
+    SnapdIcon *self = SNAPD_ICON (object);
 
     switch (prop_id) {
     case PROP_MIME_TYPE:
-        g_value_set_string (value, icon->mime_type);
+        g_value_set_string (value, self->mime_type);
         break;
     case PROP_DATA:
-        g_value_set_boxed (value, icon->data);
+        g_value_set_boxed (value, self->data);
         break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -123,10 +123,10 @@ snapd_icon_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
 static void
 snapd_icon_finalize (GObject *object)
 {
-    SnapdIcon *icon = SNAPD_ICON (object);
+    SnapdIcon *self = SNAPD_ICON (object);
 
-    g_clear_pointer (&icon->mime_type, g_free);
-    g_clear_pointer (&icon->data, g_bytes_unref);
+    g_clear_pointer (&self->mime_type, g_free);
+    g_clear_pointer (&self->data, g_bytes_unref);
 
     G_OBJECT_CLASS (snapd_icon_parent_class)->finalize (object);
 }
@@ -157,6 +157,6 @@ snapd_icon_class_init (SnapdIconClass *klass)
 }
 
 static void
-snapd_icon_init (SnapdIcon *icon)
+snapd_icon_init (SnapdIcon *self)
 {
 }
