@@ -17,6 +17,7 @@
 #include <Snapd/AuthData>
 #include <Snapd/Connection>
 #include <Snapd/Icon>
+#include <Snapd/Interface>
 #include <Snapd/Maintenance>
 #include <Snapd/Plug>
 #include <Snapd/Request>
@@ -214,6 +215,41 @@ private:
     Q_DECLARE_PRIVATE(QSnapdGetSnapRequest)
 };
 
+class QSnapdGetSnapConfRequestPrivate;
+class Q_DECL_EXPORT QSnapdGetSnapConfRequest : public QSnapdRequest
+{
+    Q_OBJECT
+
+public:
+    explicit QSnapdGetSnapConfRequest (const QString& name, const QStringList &keys, void *snapd_client, QObject *parent = 0);
+    ~QSnapdGetSnapConfRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE QHash<QString, QVariant> *configuration () const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdGetSnapConfRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdGetSnapConfRequest)
+};
+
+class QSnapdSetSnapConfRequestPrivate;
+class Q_DECL_EXPORT QSnapdSetSnapConfRequest : public QSnapdRequest
+{
+    Q_OBJECT
+
+public:
+    explicit QSnapdSetSnapConfRequest (const QString& name, const QHash<QString, QVariant> &configuration, void *snapd_client, QObject *parent = 0);
+    ~QSnapdSetSnapConfRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    void handleResult (void *, void *);
+
+private:
+    QSnapdSetSnapConfRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdSetSnapConfRequest)
+};
+
 class QSnapdGetAppsRequestPrivate;
 class Q_DECL_EXPORT QSnapdGetAppsRequest : public QSnapdRequest
 {
@@ -289,6 +325,33 @@ private:
     Q_DECLARE_PRIVATE(QSnapdAddAssertionsRequest)
 };
 
+class QSnapdGetConnectionsRequestPrivate;
+class Q_DECL_EXPORT QSnapdGetConnectionsRequest : public QSnapdRequest
+{
+    Q_OBJECT
+    Q_PROPERTY(int plugCount READ plugCount)
+    Q_PROPERTY(int slotCount READ slotCount)
+
+public:
+    explicit QSnapdGetConnectionsRequest (int flags, const QString &snap, const QString &interface, void *snapd_client, QObject *parent = 0);
+    ~QSnapdGetConnectionsRequest ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE int establishedCount () const;
+    Q_INVOKABLE QSnapdConnection *established (int) const;
+    Q_INVOKABLE int undesiredCount () const;
+    Q_INVOKABLE QSnapdConnection *undesired (int) const;
+    Q_INVOKABLE int plugCount () const;
+    Q_INVOKABLE QSnapdPlug *plug (int) const;
+    Q_INVOKABLE int slotCount () const;
+    Q_INVOKABLE QSnapdSlot *slot (int) const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdGetConnectionsRequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdGetConnectionsRequest)
+};
+
 class QSnapdGetInterfacesRequestPrivate;
 class Q_DECL_EXPORT QSnapdGetInterfacesRequest : public QSnapdRequest
 {
@@ -312,6 +375,26 @@ private:
     Q_DECLARE_PRIVATE(QSnapdGetInterfacesRequest)
 };
 
+class QSnapdGetInterfaces2RequestPrivate;
+class Q_DECL_EXPORT QSnapdGetInterfaces2Request : public QSnapdRequest
+{
+    Q_OBJECT
+    Q_PROPERTY(int interfaceCount READ interfaceCount)
+
+public:
+    explicit QSnapdGetInterfaces2Request (int flags, const QStringList &names, void *snapd_client, QObject *parent = 0);
+    ~QSnapdGetInterfaces2Request ();
+    virtual void runSync ();
+    virtual void runAsync ();
+    Q_INVOKABLE int interfaceCount () const;
+    Q_INVOKABLE QSnapdInterface *interface (int) const;
+    void handleResult (void *, void *);
+
+private:
+    QSnapdGetInterfaces2RequestPrivate *d_ptr;
+    Q_DECLARE_PRIVATE(QSnapdGetInterfaces2Request)
+};
+
 class QSnapdConnectInterfaceRequestPrivate;
 class Q_DECL_EXPORT QSnapdConnectInterfaceRequest : public QSnapdRequest
 {
@@ -789,6 +872,7 @@ class Q_DECL_EXPORT QSnapdClient : public QObject
     Q_PROPERTY(QString socketPath READ socketPath WRITE setSocketPath)
     Q_PROPERTY(QString userAgent READ userAgent WRITE setUserAgent)
     Q_PROPERTY(bool allowInteraction READ allowInteraction WRITE setAllowInteraction)
+    Q_FLAGS(GetConnectionsFlags)
     Q_FLAGS(FindFlags)
 
 public:
@@ -809,12 +893,18 @@ public:
         SelectServices = 1 << 0
     };
     Q_DECLARE_FLAGS(GetAppsFlags, GetAppsFlag);
+    enum GetConnectionsFlag
+    {
+        SelectAll = 1 << 0
+    };
+    Q_DECLARE_FLAGS(GetConnectionsFlags, GetConnectionsFlag);
     enum FindFlag
     {
         None          = 0,
         MatchName     = 1 << 0,
         SelectPrivate = 1 << 1,
-        ScopeWide     = 1 << 2
+        ScopeWide     = 1 << 2,
+        MatchCommonId = 1 << 3,
     };
     Q_DECLARE_FLAGS(FindFlags, FindFlag);
     enum InstallFlag
@@ -831,6 +921,14 @@ public:
         Known          = 1 << 1
     };
     Q_DECLARE_FLAGS(CreateUserFlags, CreateUserFlag);
+    enum InterfaceFlag
+    {
+        IncludeDocs    = 1 << 1,
+        IncludePlugs   = 1 << 2,
+        IncludeSlots   = 1 << 3,
+        OnlyConnected  = 1 << 4
+    };
+    Q_DECLARE_FLAGS(InterfaceFlags, InterfaceFlag);
     explicit QSnapdClient (QObject* parent=0);
     explicit QSnapdClient (int fd, QObject* parent=0);
     virtual ~QSnapdClient ();
@@ -861,6 +959,9 @@ public:
     Q_INVOKABLE QSnapdGetSnapsRequest *getSnaps ();
     Q_INVOKABLE Q_DECL_DEPRECATED_X("Use getSnap()") QSnapdListOneRequest *listOne (const QString &name);
     Q_INVOKABLE QSnapdGetSnapRequest *getSnap (const QString &name);
+    Q_INVOKABLE QSnapdGetSnapConfRequest *getSnapConf (const QString &name);
+    Q_INVOKABLE QSnapdGetSnapConfRequest *getSnapConf (const QString &name, const QStringList &keys);
+    Q_INVOKABLE QSnapdSetSnapConfRequest *setSnapConf (const QString &name, const QHash<QString, QVariant> &configuration);
     Q_INVOKABLE QSnapdGetAppsRequest *getApps ();
     Q_INVOKABLE QSnapdGetAppsRequest *getApps (GetAppsFlags flags);
     Q_INVOKABLE QSnapdGetAppsRequest *getApps (GetAppsFlags flags, const QStringList &snaps);
@@ -870,7 +971,15 @@ public:
     Q_INVOKABLE QSnapdGetIconRequest *getIcon (const QString &name);
     Q_INVOKABLE QSnapdGetAssertionsRequest *getAssertions (const QString &type);
     Q_INVOKABLE QSnapdAddAssertionsRequest *addAssertions (const QStringList &assertions);
+    Q_INVOKABLE QSnapdGetConnectionsRequest *getConnections ();
+    Q_INVOKABLE QSnapdGetConnectionsRequest *getConnections (GetConnectionsFlags flags);
+    Q_INVOKABLE QSnapdGetConnectionsRequest *getConnections (const QString &snap, const QString &interface);
+    Q_INVOKABLE QSnapdGetConnectionsRequest *getConnections (GetConnectionsFlags flags, const QString &snap, const QString &interface);
     Q_INVOKABLE QSnapdGetInterfacesRequest *getInterfaces ();
+    Q_INVOKABLE QSnapdGetInterfaces2Request *getInterfaces2 ();
+    Q_INVOKABLE QSnapdGetInterfaces2Request *getInterfaces2 (InterfaceFlags flags);
+    Q_INVOKABLE QSnapdGetInterfaces2Request *getInterfaces2 (const QStringList &names);
+    Q_INVOKABLE QSnapdGetInterfaces2Request *getInterfaces2 (InterfaceFlags flags, const QStringList &names);
     Q_INVOKABLE QSnapdConnectInterfaceRequest *connectInterface (const QString &plug_snap, const QString &plug_name, const QString &slot_snap, const QString &slot_name);
     Q_INVOKABLE QSnapdDisconnectInterfaceRequest *disconnectInterface (const QString &plug_snap, const QString &plug_name, const QString &slot_snap, const QString &slot_name);
     Q_INVOKABLE QSnapdFindRequest *find (const QString &query);
@@ -921,5 +1030,6 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QSnapdClient::GetAppsFlags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QSnapdClient::FindFlags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QSnapdClient::InstallFlags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QSnapdClient::CreateUserFlags)
+Q_DECLARE_OPERATORS_FOR_FLAGS(QSnapdClient::InterfaceFlags)
 
 #endif
