@@ -15,6 +15,7 @@
 #include "stream-wrapper.h"
 
 #include <QtCore/QObject>
+#include <QtCore/QVariant>
 #include <QIODevice>
 
 class QSnapdConnectRequestPrivate
@@ -148,6 +149,30 @@ public:
     SnapdSnap *snap = NULL;
 };
 
+class QSnapdGetSnapConfRequestPrivate
+{
+public:
+    QSnapdGetSnapConfRequestPrivate (const QString& name, const QStringList& keys) :
+        name(name), keys(keys) {}
+    ~QSnapdGetSnapConfRequestPrivate ()
+    {
+        if (configuration != NULL)
+            g_hash_table_unref (configuration);
+    }
+    QString name;
+    QStringList keys;
+    GHashTable *configuration = NULL;
+};
+
+class QSnapdSetSnapConfRequestPrivate
+{
+public:
+    QSnapdSetSnapConfRequestPrivate (const QString& name, const QHash<QString, QVariant>& configuration) :
+        name(name), configuration(configuration) {}
+    QString name;
+    QHash<QString, QVariant> configuration;
+};
+
 class QSnapdGetAppsRequestPrivate
 {
 public:
@@ -199,6 +224,31 @@ public:
     QStringList assertions;
 };
 
+class QSnapdGetConnectionsRequestPrivate
+{
+public:
+    QSnapdGetConnectionsRequestPrivate (int flags, const QString &snap, const QString &interface) :
+        flags (flags), snap (snap), interface (interface) {};
+    ~QSnapdGetConnectionsRequestPrivate ()
+    {
+        if (established != NULL)
+            g_ptr_array_unref (established);
+        if (undesired != NULL)
+            g_ptr_array_unref (undesired);
+        if (plugs != NULL)
+            g_ptr_array_unref (plugs);
+        if (slots_ != NULL)
+            g_ptr_array_unref (slots_);
+    }
+    int flags;
+    QString snap;
+    QString interface;
+    GPtrArray *established = NULL;
+    GPtrArray *undesired = NULL;
+    GPtrArray *plugs = NULL;
+    GPtrArray *slots_ = NULL;
+};
+
 class QSnapdGetInterfacesRequestPrivate
 {
 public:
@@ -213,6 +263,21 @@ public:
     GPtrArray *slots_ = NULL;
 };
 
+class QSnapdGetInterfaces2RequestPrivate
+{
+public:
+    QSnapdGetInterfaces2RequestPrivate (int flags, const QStringList &names) :
+        flags (flags), names (names) {};
+    ~QSnapdGetInterfaces2RequestPrivate ()
+    {
+        if (interfaces != NULL)
+            g_ptr_array_unref (interfaces);
+    }
+    int flags;
+    QStringList names;
+    GPtrArray *interfaces = NULL;
+};
+
 class QSnapdConnectInterfaceRequestPrivate
 {
 public:
