@@ -30,6 +30,8 @@ typedef struct _MockAlias MockAlias;
 typedef struct _MockApp MockApp;
 typedef struct _MockChange MockChange;
 typedef struct _MockChannel MockChannel;
+typedef struct _MockConnection MockConnection;
+typedef struct _MockInterface MockInterface;
 typedef struct _MockMedia MockMedia;
 typedef struct _MockPlug MockPlug;
 typedef struct _MockPrice MockPrice;
@@ -164,6 +166,15 @@ void            mock_change_set_ready_time        (MockChange    *change,
 MockSnap       *mock_account_add_private_snap     (MockAccount   *account,
                                                    const gchar   *name);
 
+MockInterface  *mock_snapd_add_interface          (MockSnapd     *snapd,
+                                                   const gchar   *name);
+
+void            mock_interface_set_summary        (MockInterface *interface,
+                                                   const gchar   *summary);
+
+void            mock_interface_set_doc_url        (MockInterface *interface,
+                                                   const gchar   *url);
+
 MockSnap       *mock_snapd_add_snap               (MockSnapd     *snapd,
                                                    const gchar   *name);
 
@@ -218,8 +229,14 @@ void            mock_snap_set_channel             (MockSnap      *snap,
 
 const gchar    *mock_snap_get_channel             (MockSnap      *snap);
 
-void            mock_snap_add_common_id           (MockSnap      *snap,
-                                                   const gchar   *id);
+void            mock_snap_set_conf                (MockSnap      *snap,
+                                                   const gchar   *name,
+                                                   const gchar   *value);
+
+gsize           mock_snap_get_conf_count          (MockSnap      *snap);
+
+const gchar    *mock_snap_get_conf                (MockSnap      *snap,
+                                                   const gchar   *name);
 
 MockTrack      *mock_snap_add_track               (MockSnap      *snap,
                                                    const gchar   *name);
@@ -371,21 +388,38 @@ void            mock_snap_add_store_section       (MockSnap      *snap,
                                                    const gchar   *section);
 
 MockPlug       *mock_snap_add_plug                (MockSnap      *snap,
+                                                   MockInterface *interface,
                                                    const gchar   *name);
 
 MockPlug       *mock_snap_find_plug               (MockSnap      *snap,
                                                    const gchar   *name);
 
+void            mock_plug_add_attribute           (MockPlug      *plug,
+                                                   const gchar   *name,
+                                                   const gchar   *value);
+
 MockSlot       *mock_snap_add_slot                (MockSnap      *snap,
+                                                   MockInterface *interface,
                                                    const gchar   *name);
 
 MockSlot       *mock_snap_find_slot               (MockSnap      *snap,
                                                    const gchar   *name);
 
-void            mock_plug_set_connection          (MockPlug      *plug,
-                                                   MockSlot      *slot);
+void            mock_slot_add_attribute           (MockSlot      *slot,
+                                                   const gchar   *name,
+                                                   const gchar   *value);
 
-MockSlot       *mock_plug_get_connection          (MockPlug      *plug);
+void            mock_snapd_connect                (MockSnapd     *snapd,
+                                                   MockPlug      *plug,
+                                                   MockSlot      *slot,
+                                                   gboolean       manual,
+                                                   gboolean       gadget);
+
+MockSlot       *mock_snapd_find_plug_connection   (MockSnapd     *snapd,
+                                                   MockPlug      *plug);
+
+GList          *mock_snapd_find_slot_connections  (MockSnapd     *snapd,
+                                                   MockSlot      *slot);
 
 void            mock_snapd_add_assertion          (MockSnapd     *snapd,
                                                    const gchar   *assertion);
