@@ -199,6 +199,41 @@ public slots:
     void onComplete ();
 };
 
+class GetSnapConfHandler: public QObject
+{
+    Q_OBJECT
+
+public:
+    GetSnapConfHandler (GMainLoop *loop, QSnapdGetSnapConfRequest *request) : loop (loop), request (request) {}
+    GMainLoop *loop;
+    QSnapdGetSnapConfRequest *request;
+    ~GetSnapConfHandler ()
+    {
+        delete request;
+    }
+
+public slots:
+    void onComplete ();
+};
+
+class SetSnapConfHandler: public QObject
+{
+    Q_OBJECT
+
+public:
+    SetSnapConfHandler (GMainLoop *loop, MockSnapd *snapd, QSnapdSetSnapConfRequest *request) : loop (loop), snapd (snapd), request (request) {}
+    GMainLoop *loop;
+    MockSnapd *snapd;
+    QSnapdSetSnapConfRequest *request;
+    ~SetSnapConfHandler ()
+    {
+        delete request;
+    }
+
+public slots:
+    void onComplete ();
+};
+
 class GetAppsHandler: public QObject
 {
     Q_OBJECT
@@ -233,6 +268,23 @@ public slots:
     void onComplete ();
 };
 
+class GetConnectionsHandler: public QObject
+{
+    Q_OBJECT
+
+public:
+    GetConnectionsHandler (GMainLoop *loop, QSnapdGetConnectionsRequest *request) : loop (loop), request (request) {}
+    GMainLoop *loop;
+    QSnapdGetConnectionsRequest *request;
+    ~GetConnectionsHandler ()
+    {
+        delete request;
+    }
+
+public slots:
+    void onComplete ();
+};
+
 class GetInterfacesHandler: public QObject
 {
     Q_OBJECT
@@ -250,6 +302,23 @@ public slots:
     void onComplete ();
 };
 
+class GetInterfaces2Handler: public QObject
+{
+    Q_OBJECT
+
+public:
+    GetInterfaces2Handler (GMainLoop *loop, QSnapdGetInterfaces2Request *request) : loop (loop), request (request) {}
+    GMainLoop *loop;
+    QSnapdGetInterfaces2Request *request;
+    ~GetInterfaces2Handler ()
+    {
+        delete request;
+    }
+
+public slots:
+    void onComplete ();
+};
+
 class ConnectInterfaceHandler: public QObject
 {
     Q_OBJECT
